#include <iostream>
#include <vector>
using namespace std;

struct Data{
	int value;
	pair<bool,int> lazy;
	int left,right;
	bool needPropagate(){
		return lazy.first || lazy.second != 0;
	}
	void apply(pair<bool,int> op){
		if(op.first){ // with reset
			value=op.second*(right-left+1);
			lazy=op;
		}else{
			value += op.second*(right-left+1);
			lazy.second += op.second;
		}
	}
};

int combine(int a,int b){ return a+b; }
struct SegTree{
	vector<Data> tree;
	SegTree(vector<int> &data){
		int n=1;
		while(n < 2*data.size()){
			n*=2;
		}
		tree.resize(n);
		for(int i=0;i<n/2;i++){
			tree[n/2+i].value = i<data.size()?data[i]:0;
			tree[n/2+i].left = tree[n/2+i].right=i;
		}
		for(int i=n/2-1;i>=1;i--){
			tree[i].value = combine(tree[2*i].value, tree[2*i+1].value);
			tree[i].left = tree[2*i].left;
			tree[i].right = tree[2*i+1].right;
		}
	}
	void propagate(int i){
		if(!tree[i].needPropagate()) return;
		for(int k:{0, 1}){
			update(2*i+k, tree[i].left, tree[i].right, tree[i].lazy);
		}
		tree[i].lazy={false, 0}; // nop
	}
	int query(int i, int l, int r){
		if(l <= tree[i].left && tree[i].right <= r){
			return tree[i].value;
		}
		if(tree[i].right < l || r < tree[i].left){
			return 0;
		}
		propagate(i);
		return combine(query(2*i, l, r), query(2*i+1, l, r));
	}
	void update(int i, int l, int r, pair<bool,int> op){
		if(l <= tree[i].left && tree[i].right <= r){
			tree[i].apply(op);
			return;
		}
		if(tree[i].right < l || r < tree[i].left){
			return;
		}
		propagate(i);
		for(int k:{0, 1}){
			update(2*i+k, l, r, op);
		}
		tree[i].value = combine(tree[2*i].value, tree[2*i+1].value);
	}
};
	
int main(){
	int n;
	cin>>n;
	vector<int> initial(n);
	for(int i=0;i<n;i++){
		cin>>initial[i];
	}
	auto tree=SegTree(initial);
	int q;
	cin>>q;
	for(int i=0;i<q;i++){
		char c;
		cin>>c;
		switch(c){
			case 'Q':{ // query range
				int l,r;
				cin>>l>>r;
				cout<<tree.query(1,l,r)<<'\n';
			}break;
			case 'A':{ // add to each element in range
				int l,r,v;
				cin>>l>>r>>v;
				tree.update(1,l,r,{false,v});
			}break;
			case 'U':{ // update range
				int l,r,v;
				cin>>l>>r>>v;
				tree.update(1,l,r,{true,v});
			}break;
			default: return 1;
		}
	}
}
